/**
 * Routines to lookup MQ Completion Codes and Reason Codes
 * and return the string version of the integer.
 *
 * @copyright Copyright(C), 2019-2020, Capitalware Inc.
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.0.0
 * @license Apache 2 License
 *
 * ==================================================================
 * CHANGE HISTORY for mqlookup.h
 * ------------------------------------------------------------------
 * Date       Change-id   Produced  User Name
 * yyyymmdd               Version.
 *                        rr.ss.uu
 * Reason
 * ------------------------------------------------------------------
 * 20201126   RML000      01.00.00  R. Lacroix
 * Birth.
 *
 *
 * ------------------------------------------------------------------
 */
#ifndef __MQ_LOOKUP
#define __MQ_LOOKUP 1 /*Indicate that this file has been included.*/

#define NOT_FOUND          -1

/**
 * Structure for all look up tables.
 */
typedef struct MQ_LOOK_UP_S
{
   int         Index;
   char        *pString;
} MQ_LOOK_UP_T;

/**
 * All of the current MQ Completion Codes from IBM MQ v9.2.
 */
static MQ_LOOK_UP_T COMPLETION_CODES[] =
{
   {-1, "MQCC_UNKNOWN"},
   { 0, "MQCC_OK"},
   { 1, "MQCC_WARNING"},
   { 2, "MQCC_FAILED"}
};

static int COMPLETION_CODES_SIZE = sizeof(COMPLETION_CODES) / sizeof(MQ_LOOK_UP_T);


/**
 * All of the current MQ Reason Codes from IBM MQ v9.2.
 */
static MQ_LOOK_UP_T REASON_CODES[] =
{
   {    0, "MQRC_NONE"},
   { 2001, "MQRC_ALIAS_BASE_Q_TYPE_ERROR"},
   { 2002, "MQRC_ALREADY_CONNECTED"},
   { 2003, "MQRC_BACKED_OUT"},
   { 2004, "MQRC_BUFFER_ERROR"},
   { 2005, "MQRC_BUFFER_LENGTH_ERROR"},
   { 2006, "MQRC_CHAR_ATTR_LENGTH_ERROR"},
   { 2007, "MQRC_CHAR_ATTRS_ERROR"},
   { 2008, "MQRC_CHAR_ATTRS_TOO_SHORT"},
   { 2009, "MQRC_CONNECTION_BROKEN"},
   { 2010, "MQRC_DATA_LENGTH_ERROR"},
   { 2011, "MQRC_DYNAMIC_Q_NAME_ERROR"},
   { 2012, "MQRC_ENVIRONMENT_ERROR"},
   { 2013, "MQRC_EXPIRY_ERROR"},
   { 2014, "MQRC_FEEDBACK_ERROR"},
   { 2016, "MQRC_GET_INHIBITED"},
   { 2017, "MQRC_HANDLE_NOT_AVAILABLE"},
   { 2018, "MQRC_HCONN_ERROR"},
   { 2019, "MQRC_HOBJ_ERROR"},
   { 2020, "MQRC_INHIBIT_VALUE_ERROR"},
   { 2021, "MQRC_INT_ATTR_COUNT_ERROR"},
   { 2022, "MQRC_INT_ATTR_COUNT_TOO_SMALL"},
   { 2023, "MQRC_INT_ATTRS_ARRAY_ERROR"},
   { 2024, "MQRC_SYNCPOINT_LIMIT_REACHED"},
   { 2025, "MQRC_MAX_CONNS_LIMIT_REACHED"},
   { 2026, "MQRC_MD_ERROR"},
   { 2027, "MQRC_MISSING_REPLY_TO_Q"},
   { 2029, "MQRC_MSG_TYPE_ERROR"},
   { 2030, "MQRC_MSG_TOO_BIG_FOR_Q"},
   { 2031, "MQRC_MSG_TOO_BIG_FOR_Q_MGR"},
   { 2033, "MQRC_NO_MSG_AVAILABLE"},
   { 2034, "MQRC_NO_MSG_UNDER_CURSOR"},
   { 2035, "MQRC_NOT_AUTHORIZED"},
   { 2036, "MQRC_NOT_OPEN_FOR_BROWSE"},
   { 2037, "MQRC_NOT_OPEN_FOR_INPUT"},
   { 2038, "MQRC_NOT_OPEN_FOR_INQUIRE"},
   { 2039, "MQRC_NOT_OPEN_FOR_OUTPUT"},
   { 2040, "MQRC_NOT_OPEN_FOR_SET"},
   { 2041, "MQRC_OBJECT_CHANGED"},
   { 2042, "MQRC_OBJECT_IN_USE"},
   { 2043, "MQRC_OBJECT_TYPE_ERROR"},
   { 2044, "MQRC_OD_ERROR"},
   { 2045, "MQRC_OPTION_NOT_VALID_FOR_TYPE"},
   { 2046, "MQRC_OPTIONS_ERROR"},
   { 2047, "MQRC_PERSISTENCE_ERROR"},
   { 2048, "MQRC_PERSISTENT_NOT_ALLOWED"},
   { 2049, "MQRC_PRIORITY_EXCEEDS_MAXIMUM"},
   { 2050, "MQRC_PRIORITY_ERROR"},
   { 2051, "MQRC_PUT_INHIBITED"},
   { 2052, "MQRC_Q_DELETED"},
   { 2053, "MQRC_Q_FULL"},
   { 2055, "MQRC_Q_NOT_EMPTY"},
   { 2056, "MQRC_Q_SPACE_NOT_AVAILABLE"},
   { 2057, "MQRC_Q_TYPE_ERROR"},
   { 2058, "MQRC_Q_MGR_NAME_ERROR"},
   { 2059, "MQRC_Q_MGR_NOT_AVAILABLE"},
   { 2061, "MQRC_REPORT_OPTIONS_ERROR"},
   { 2062, "MQRC_SECOND_MARK_NOT_ALLOWED"},
   { 2063, "MQRC_SECURITY_ERROR"},
   { 2065, "MQRC_SELECTOR_COUNT_ERROR"},
   { 2066, "MQRC_SELECTOR_LIMIT_EXCEEDED"},
   { 2067, "MQRC_SELECTOR_ERROR"},
   { 2068, "MQRC_SELECTOR_NOT_FOR_TYPE"},
   { 2069, "MQRC_SIGNAL_OUTSTANDING"},
   { 2070, "MQRC_SIGNAL_REQUEST_ACCEPTED"},
   { 2071, "MQRC_STORAGE_NOT_AVAILABLE"},
   { 2072, "MQRC_SYNCPOINT_NOT_AVAILABLE"},
   { 2075, "MQRC_TRIGGER_CONTROL_ERROR"},
   { 2076, "MQRC_TRIGGER_DEPTH_ERROR"},
   { 2077, "MQRC_TRIGGER_MSG_PRIORITY_ERR"},
   { 2078, "MQRC_TRIGGER_TYPE_ERROR"},
   { 2079, "MQRC_TRUNCATED_MSG_ACCEPTED"},
   { 2080, "MQRC_TRUNCATED_MSG_FAILED"},
   { 2082, "MQRC_UNKNOWN_ALIAS_BASE_Q"},
   { 2085, "MQRC_UNKNOWN_OBJECT_NAME"},
   { 2086, "MQRC_UNKNOWN_OBJECT_Q_MGR"},
   { 2087, "MQRC_UNKNOWN_REMOTE_Q_MGR"},
   { 2090, "MQRC_WAIT_INTERVAL_ERROR"},
   { 2091, "MQRC_XMIT_Q_TYPE_ERROR"},
   { 2092, "MQRC_XMIT_Q_USAGE_ERROR"},
   { 2093, "MQRC_NOT_OPEN_FOR_PASS_ALL"},
   { 2094, "MQRC_NOT_OPEN_FOR_PASS_IDENT"},
   { 2095, "MQRC_NOT_OPEN_FOR_SET_ALL"},
   { 2096, "MQRC_NOT_OPEN_FOR_SET_IDENT"},
   { 2097, "MQRC_CONTEXT_HANDLE_ERROR"},
   { 2098, "MQRC_CONTEXT_NOT_AVAILABLE"},
   { 2099, "MQRC_SIGNAL1_ERROR"},
   { 2100, "MQRC_OBJECT_ALREADY_EXISTS"},
   { 2101, "MQRC_OBJECT_DAMAGED"},
   { 2102, "MQRC_RESOURCE_PROBLEM"},
   { 2103, "MQRC_ANOTHER_Q_MGR_CONNECTED"},
   { 2104, "MQRC_UNKNOWN_REPORT_OPTION"},
   { 2105, "MQRC_STORAGE_CLASS_ERROR"},
   { 2106, "MQRC_COD_NOT_VALID_FOR_XCF_Q"},
   { 2107, "MQRC_XWAIT_CANCELED"},
   { 2108, "MQRC_XWAIT_ERROR"},
   { 2109, "MQRC_SUPPRESSED_BY_EXIT"},
   { 2110, "MQRC_FORMAT_ERROR"},
   { 2111, "MQRC_SOURCE_CCSID_ERROR"},
   { 2112, "MQRC_SOURCE_INTEGER_ENC_ERROR"},
   { 2113, "MQRC_SOURCE_DECIMAL_ENC_ERROR"},
   { 2114, "MQRC_SOURCE_FLOAT_ENC_ERROR"},
   { 2115, "MQRC_TARGET_CCSID_ERROR"},
   { 2116, "MQRC_TARGET_INTEGER_ENC_ERROR"},
   { 2117, "MQRC_TARGET_DECIMAL_ENC_ERROR"},
   { 2118, "MQRC_TARGET_FLOAT_ENC_ERROR"},
   { 2119, "MQRC_NOT_CONVERTED"},
   { 2121, "MQRC_NO_EXTERNAL_PARTICIPANTS"},
   { 2122, "MQRC_PARTICIPANT_NOT_AVAILABLE"},
   { 2123, "MQRC_OUTCOME_MIXED"},
   { 2124, "MQRC_OUTCOME_PENDING"},
   { 2125, "MQRC_BRIDGE_STARTED"},
   { 2126, "MQRC_BRIDGE_STOPPED"},
   { 2127, "MQRC_ADAPTER_STORAGE_SHORTAGE"},
   { 2128, "MQRC_UOW_IN_PROGRESS"},
   { 2129, "MQRC_ADAPTER_CONN_LOAD_ERROR"},
   { 2130, "MQRC_ADAPTER_SERV_LOAD_ERROR"},
   { 2131, "MQRC_ADAPTER_DEFS_ERROR"},
   { 2132, "MQRC_ADAPTER_DEFS_LOAD_ERROR"},
   { 2133, "MQRC_ADAPTER_CONV_LOAD_ERROR"},
   { 2134, "MQRC_BO_ERROR"},
   { 2135, "MQRC_DH_ERROR"},
   { 2136, "MQRC_MULTIPLE_REASONS"},
   { 2137, "MQRC_OPEN_FAILED"},
   { 2138, "MQRC_ADAPTER_DISC_LOAD_ERROR"},
   { 2139, "MQRC_CNO_ERROR"},
   { 2140, "MQRC_CICS_WAIT_FAILED"},
   { 2141, "MQRC_DLH_ERROR"},
   { 2142, "MQRC_HEADER_ERROR"},
   { 2143, "MQRC_SOURCE_LENGTH_ERROR"},
   { 2144, "MQRC_TARGET_LENGTH_ERROR"},
   { 2145, "MQRC_SOURCE_BUFFER_ERROR"},
   { 2146, "MQRC_TARGET_BUFFER_ERROR"},
   { 2147, "MQRC_INCOMPLETE_TRANSACTION"},
   { 2148, "MQRC_IIH_ERROR"},
   { 2149, "MQRC_PCF_ERROR"},
   { 2150, "MQRC_DBCS_ERROR"},
   { 2152, "MQRC_OBJECT_NAME_ERROR"},
   { 2153, "MQRC_OBJECT_Q_MGR_NAME_ERROR"},
   { 2154, "MQRC_RECS_PRESENT_ERROR"},
   { 2155, "MQRC_OBJECT_RECORDS_ERROR"},
   { 2156, "MQRC_RESPONSE_RECORDS_ERROR"},
   { 2157, "MQRC_ASID_MISMATCH"},
   { 2158, "MQRC_PMO_RECORD_FLAGS_ERROR"},
   { 2159, "MQRC_PUT_MSG_RECORDS_ERROR"},
   { 2160, "MQRC_CONN_ID_IN_USE"},
   { 2161, "MQRC_Q_MGR_QUIESCING"},
   { 2162, "MQRC_Q_MGR_STOPPING"},
   { 2163, "MQRC_DUPLICATE_RECOV_COORD"},
   { 2173, "MQRC_PMO_ERROR"},
   { 2182, "MQRC_API_EXIT_NOT_FOUND"},
   { 2183, "MQRC_API_EXIT_LOAD_ERROR"},
   { 2184, "MQRC_REMOTE_Q_NAME_ERROR"},
   { 2185, "MQRC_INCONSISTENT_PERSISTENCE"},
   { 2186, "MQRC_GMO_ERROR"},
   { 2187, "MQRC_CICS_BRIDGE_RESTRICTION"},
   { 2188, "MQRC_STOPPED_BY_CLUSTER_EXIT"},
   { 2189, "MQRC_CLUSTER_RESOLUTION_ERROR"},
   { 2190, "MQRC_CONVERTED_STRING_TOO_BIG"},
   { 2191, "MQRC_TMC_ERROR"},
   { 2192, "MQRC_STORAGE_MEDIUM_FULL"},
   { 2193, "MQRC_PAGESET_ERROR"},
   { 2194, "MQRC_NAME_NOT_VALID_FOR_TYPE"},
   { 2195, "MQRC_UNEXPECTED_ERROR"},
   { 2196, "MQRC_UNKNOWN_XMIT_Q"},
   { 2197, "MQRC_UNKNOWN_DEF_XMIT_Q"},
   { 2198, "MQRC_DEF_XMIT_Q_TYPE_ERROR"},
   { 2199, "MQRC_DEF_XMIT_Q_USAGE_ERROR"},
   { 2200, "MQRC_MSG_MARKED_BROWSE_CO_OP"},
   { 2201, "MQRC_NAME_IN_USE"},
   { 2202, "MQRC_CONNECTION_QUIESCING"},
   { 2203, "MQRC_CONNECTION_STOPPING"},
   { 2204, "MQRC_ADAPTER_NOT_AVAILABLE"},
   { 2206, "MQRC_MSG_ID_ERROR"},
   { 2207, "MQRC_CORREL_ID_ERROR"},
   { 2208, "MQRC_FILE_SYSTEM_ERROR"},
   { 2209, "MQRC_NO_MSG_LOCKED"},
   { 2210, "MQRC_SOAP_DOTNET_ERROR"},
   { 2211, "MQRC_SOAP_AXIS_ERROR"},
   { 2212, "MQRC_SOAP_URL_ERROR"},
   { 2216, "MQRC_FILE_NOT_AUDITED"},
   { 2217, "MQRC_CONNECTION_NOT_AUTHORIZED"},
   { 2218, "MQRC_MSG_TOO_BIG_FOR_CHANNEL"},
   { 2219, "MQRC_CALL_IN_PROGRESS"},
   { 2220, "MQRC_RMH_ERROR"},
   { 2222, "MQRC_Q_MGR_ACTIVE"},
   { 2223, "MQRC_Q_MGR_NOT_ACTIVE"},
   { 2224, "MQRC_Q_DEPTH_HIGH"},
   { 2225, "MQRC_Q_DEPTH_LOW"},
   { 2226, "MQRC_Q_SERVICE_INTERVAL_HIGH"},
   { 2227, "MQRC_Q_SERVICE_INTERVAL_OK"},
   { 2228, "MQRC_RFH_HEADER_FIELD_ERROR"},
   { 2229, "MQRC_RAS_PROPERTY_ERROR"},
   { 2232, "MQRC_UNIT_OF_WORK_NOT_STARTED"},
   { 2233, "MQRC_CHANNEL_AUTO_DEF_OK"},
   { 2234, "MQRC_CHANNEL_AUTO_DEF_ERROR"},
   { 2235, "MQRC_CFH_ERROR"},
   { 2236, "MQRC_CFIL_ERROR"},
   { 2237, "MQRC_CFIN_ERROR"},
   { 2238, "MQRC_CFSL_ERROR"},
   { 2239, "MQRC_CFST_ERROR"},
   { 2241, "MQRC_INCOMPLETE_GROUP"},
   { 2242, "MQRC_INCOMPLETE_MSG"},
   { 2243, "MQRC_INCONSISTENT_CCSIDS"},
   { 2244, "MQRC_INCONSISTENT_ENCODINGS"},
   { 2245, "MQRC_INCONSISTENT_UOW"},
   { 2246, "MQRC_INVALID_MSG_UNDER_CURSOR"},
   { 2247, "MQRC_MATCH_OPTIONS_ERROR"},
   { 2248, "MQRC_MDE_ERROR"},
   { 2249, "MQRC_MSG_FLAGS_ERROR"},
   { 2250, "MQRC_MSG_SEQ_NUMBER_ERROR"},
   { 2251, "MQRC_OFFSET_ERROR"},
   { 2252, "MQRC_ORIGINAL_LENGTH_ERROR"},
   { 2253, "MQRC_SEGMENT_LENGTH_ZERO"},
   { 2255, "MQRC_UOW_NOT_AVAILABLE"},
   { 2256, "MQRC_WRONG_GMO_VERSION"},
   { 2257, "MQRC_WRONG_MD_VERSION"},
   { 2258, "MQRC_GROUP_ID_ERROR"},
   { 2259, "MQRC_INCONSISTENT_BROWSE"},
   { 2260, "MQRC_XQH_ERROR"},
   { 2261, "MQRC_SRC_ENV_ERROR"},
   { 2262, "MQRC_SRC_NAME_ERROR"},
   { 2263, "MQRC_DEST_ENV_ERROR"},
   { 2264, "MQRC_DEST_NAME_ERROR"},
   { 2265, "MQRC_TM_ERROR"},
   { 2266, "MQRC_CLUSTER_EXIT_ERROR"},
   { 2267, "MQRC_CLUSTER_EXIT_LOAD_ERROR"},
   { 2268, "MQRC_CLUSTER_PUT_INHIBITED"},
   { 2269, "MQRC_CLUSTER_RESOURCE_ERROR"},
   { 2270, "MQRC_NO_DESTINATIONS_AVAILABLE"},
   { 2271, "MQRC_CONN_TAG_IN_USE"},
   { 2272, "MQRC_PARTIALLY_CONVERTED"},
   { 2273, "MQRC_CONNECTION_ERROR"},
   { 2274, "MQRC_OPTION_ENVIRONMENT_ERROR"},
   { 2277, "MQRC_CD_ERROR"},
   { 2278, "MQRC_CLIENT_CONN_ERROR"},
   { 2279, "MQRC_CHANNEL_STOPPED_BY_USER"},
   { 2280, "MQRC_HCONFIG_ERROR"},
   { 2281, "MQRC_FUNCTION_ERROR"},
   { 2282, "MQRC_CHANNEL_STARTED"},
   { 2283, "MQRC_CHANNEL_STOPPED"},
   { 2284, "MQRC_CHANNEL_CONV_ERROR"},
   { 2285, "MQRC_SERVICE_NOT_AVAILABLE"},
   { 2286, "MQRC_INITIALIZATION_FAILED"},
   { 2287, "MQRC_TERMINATION_FAILED"},
   { 2288, "MQRC_UNKNOWN_Q_NAME"},
   { 2289, "MQRC_SERVICE_ERROR"},
   { 2290, "MQRC_Q_ALREADY_EXISTS"},
   { 2291, "MQRC_USER_ID_NOT_AVAILABLE"},
   { 2292, "MQRC_UNKNOWN_ENTITY"},
   { 2293, "MQRC_UNKNOWN_AUTH_ENTITY"},
   { 2294, "MQRC_UNKNOWN_REF_OBJECT"},
   { 2295, "MQRC_CHANNEL_ACTIVATED"},
   { 2296, "MQRC_CHANNEL_NOT_ACTIVATED"},
   { 2297, "MQRC_UOW_CANCELED"},
   { 2298, "MQRC_FUNCTION_NOT_SUPPORTED"},
   { 2299, "MQRC_SELECTOR_TYPE_ERROR"},
   { 2300, "MQRC_COMMAND_TYPE_ERROR"},
   { 2301, "MQRC_MULTIPLE_INSTANCE_ERROR"},
   { 2302, "MQRC_SYSTEM_ITEM_NOT_ALTERABLE"},
   { 2303, "MQRC_BAG_CONVERSION_ERROR"},
   { 2304, "MQRC_SELECTOR_OUT_OF_RANGE"},
   { 2305, "MQRC_SELECTOR_NOT_UNIQUE"},
   { 2306, "MQRC_INDEX_NOT_PRESENT"},
   { 2307, "MQRC_STRING_ERROR"},
   { 2308, "MQRC_ENCODING_NOT_SUPPORTED"},
   { 2309, "MQRC_SELECTOR_NOT_PRESENT"},
   { 2310, "MQRC_OUT_SELECTOR_ERROR"},
   { 2311, "MQRC_STRING_TRUNCATED"},
   { 2312, "MQRC_SELECTOR_WRONG_TYPE"},
   { 2313, "MQRC_INCONSISTENT_ITEM_TYPE"},
   { 2314, "MQRC_INDEX_ERROR"},
   { 2315, "MQRC_SYSTEM_BAG_NOT_ALTERABLE"},
   { 2316, "MQRC_ITEM_COUNT_ERROR"},
   { 2317, "MQRC_FORMAT_NOT_SUPPORTED"},
   { 2318, "MQRC_SELECTOR_NOT_SUPPORTED"},
   { 2319, "MQRC_ITEM_VALUE_ERROR"},
   { 2320, "MQRC_HBAG_ERROR"},
   { 2321, "MQRC_PARAMETER_MISSING"},
   { 2322, "MQRC_CMD_SERVER_NOT_AVAILABLE"},
   { 2323, "MQRC_STRING_LENGTH_ERROR"},
   { 2324, "MQRC_INQUIRY_COMMAND_ERROR"},
   { 2325, "MQRC_NESTED_BAG_NOT_SUPPORTED"},
   { 2326, "MQRC_BAG_WRONG_TYPE"},
   { 2327, "MQRC_ITEM_TYPE_ERROR"},
   { 2328, "MQRC_SYSTEM_BAG_NOT_DELETABLE"},
   { 2329, "MQRC_SYSTEM_ITEM_NOT_DELETABLE"},
   { 2330, "MQRC_CODED_CHAR_SET_ID_ERROR"},
   { 2331, "MQRC_MSG_TOKEN_ERROR"},
   { 2332, "MQRC_MISSING_WIH"},
   { 2333, "MQRC_WIH_ERROR"},
   { 2334, "MQRC_RFH_ERROR"},
   { 2335, "MQRC_RFH_STRING_ERROR"},
   { 2336, "MQRC_RFH_COMMAND_ERROR"},
   { 2337, "MQRC_RFH_PARM_ERROR"},
   { 2338, "MQRC_RFH_DUPLICATE_PARM"},
   { 2339, "MQRC_RFH_PARM_MISSING"},
   { 2340, "MQRC_CHAR_CONVERSION_ERROR"},
   { 2341, "MQRC_UCS2_CONVERSION_ERROR"},
   { 2342, "MQRC_DB2_NOT_AVAILABLE"},
   { 2343, "MQRC_OBJECT_NOT_UNIQUE"},
   { 2344, "MQRC_CONN_TAG_NOT_RELEASED"},
   { 2345, "MQRC_CF_NOT_AVAILABLE"},
   { 2346, "MQRC_CF_STRUC_IN_USE"},
   { 2347, "MQRC_CF_STRUC_LIST_HDR_IN_USE"},
   { 2348, "MQRC_CF_STRUC_AUTH_FAILED"},
   { 2349, "MQRC_CF_STRUC_ERROR"},
   { 2350, "MQRC_CONN_TAG_NOT_USABLE"},
   { 2351, "MQRC_GLOBAL_UOW_CONFLICT"},
   { 2352, "MQRC_LOCAL_UOW_CONFLICT"},
   { 2353, "MQRC_HANDLE_IN_USE_FOR_UOW"},
   { 2354, "MQRC_UOW_ENLISTMENT_ERROR"},
   { 2355, "MQRC_UOW_MIX_NOT_SUPPORTED"},
   { 2356, "MQRC_WXP_ERROR"},
   { 2357, "MQRC_CURRENT_RECORD_ERROR"},
   { 2358, "MQRC_NEXT_OFFSET_ERROR"},
   { 2359, "MQRC_NO_RECORD_AVAILABLE"},
   { 2360, "MQRC_OBJECT_LEVEL_INCOMPATIBLE"},
   { 2361, "MQRC_NEXT_RECORD_ERROR"},
   { 2362, "MQRC_BACKOUT_THRESHOLD_REACHED"},
   { 2363, "MQRC_MSG_NOT_MATCHED"},
   { 2364, "MQRC_JMS_FORMAT_ERROR"},
   { 2365, "MQRC_SEGMENTS_NOT_SUPPORTED"},
   { 2366, "MQRC_WRONG_CF_LEVEL"},
   { 2367, "MQRC_CONFIG_CREATE_OBJECT"},
   { 2368, "MQRC_CONFIG_CHANGE_OBJECT"},
   { 2369, "MQRC_CONFIG_DELETE_OBJECT"},
   { 2370, "MQRC_CONFIG_REFRESH_OBJECT"},
   { 2371, "MQRC_CHANNEL_SSL_ERROR"},
   { 2372, "MQRC_PARTICIPANT_NOT_DEFINED"},
   { 2373, "MQRC_CF_STRUC_FAILED"},
   { 2374, "MQRC_API_EXIT_ERROR"},
   { 2375, "MQRC_API_EXIT_INIT_ERROR"},
   { 2376, "MQRC_API_EXIT_TERM_ERROR"},
   { 2377, "MQRC_EXIT_REASON_ERROR"},
   { 2378, "MQRC_RESERVED_VALUE_ERROR"},
   { 2379, "MQRC_NO_DATA_AVAILABLE"},
   { 2380, "MQRC_SCO_ERROR"},
   { 2381, "MQRC_KEY_REPOSITORY_ERROR"},
   { 2382, "MQRC_CRYPTO_HARDWARE_ERROR"},
   { 2383, "MQRC_AUTH_INFO_REC_COUNT_ERROR"},
   { 2384, "MQRC_AUTH_INFO_REC_ERROR"},
   { 2385, "MQRC_AIR_ERROR"},
   { 2386, "MQRC_AUTH_INFO_TYPE_ERROR"},
   { 2387, "MQRC_AUTH_INFO_CONN_NAME_ERROR"},
   { 2388, "MQRC_LDAP_USER_NAME_ERROR"},
   { 2389, "MQRC_LDAP_USER_NAME_LENGTH_ERR"},
   { 2390, "MQRC_LDAP_PASSWORD_ERROR"},
   { 2391, "MQRC_SSL_ALREADY_INITIALIZED"},
   { 2392, "MQRC_SSL_CONFIG_ERROR"},
   { 2393, "MQRC_SSL_INITIALIZATION_ERROR"},
   { 2394, "MQRC_Q_INDEX_TYPE_ERROR"},
   { 2395, "MQRC_CFBS_ERROR"},
   { 2396, "MQRC_SSL_NOT_ALLOWED"},
   { 2397, "MQRC_JSSE_ERROR"},
   { 2398, "MQRC_SSL_PEER_NAME_MISMATCH"},
   { 2399, "MQRC_SSL_PEER_NAME_ERROR"},
   { 2400, "MQRC_UNSUPPORTED_CIPHER_SUITE"},
   { 2401, "MQRC_SSL_CERTIFICATE_REVOKED"},
   { 2402, "MQRC_SSL_CERT_STORE_ERROR"},
   { 2406, "MQRC_CLIENT_EXIT_LOAD_ERROR"},
   { 2407, "MQRC_CLIENT_EXIT_ERROR"},
   { 2408, "MQRC_UOW_COMMITTED"},
   { 2409, "MQRC_SSL_KEY_RESET_ERROR"},
   { 2410, "MQRC_UNKNOWN_COMPONENT_NAME"},
   { 2411, "MQRC_LOGGER_STATUS"},
   { 2412, "MQRC_COMMAND_MQSC"},
   { 2413, "MQRC_COMMAND_PCF"},
   { 2414, "MQRC_CFIF_ERROR"},
   { 2415, "MQRC_CFSF_ERROR"},
   { 2416, "MQRC_CFGR_ERROR"},
   { 2417, "MQRC_MSG_NOT_ALLOWED_IN_GROUP"},
   { 2418, "MQRC_FILTER_OPERATOR_ERROR"},
   { 2419, "MQRC_NESTED_SELECTOR_ERROR"},
   { 2420, "MQRC_EPH_ERROR"},
   { 2421, "MQRC_RFH_FORMAT_ERROR"},
   { 2422, "MQRC_CFBF_ERROR"},
   { 2423, "MQRC_CLIENT_CHANNEL_CONFLICT"},
   { 2424, "MQRC_SD_ERROR"},
   { 2425, "MQRC_TOPIC_STRING_ERROR"},
   { 2426, "MQRC_STS_ERROR"},
   { 2428, "MQRC_NO_SUBSCRIPTION"},
   { 2429, "MQRC_SUBSCRIPTION_IN_USE"},
   { 2430, "MQRC_STAT_TYPE_ERROR"},
   { 2431, "MQRC_SUB_USER_DATA_ERROR"},
   { 2432, "MQRC_SUB_ALREADY_EXISTS"},
   { 2434, "MQRC_IDENTITY_MISMATCH"},
   { 2435, "MQRC_ALTER_SUB_ERROR"},
   { 2436, "MQRC_DURABILITY_NOT_ALLOWED"},
   { 2437, "MQRC_NO_RETAINED_MSG"},
   { 2438, "MQRC_SRO_ERROR"},
   { 2440, "MQRC_SUB_NAME_ERROR"},
   { 2441, "MQRC_OBJECT_STRING_ERROR"},
   { 2442, "MQRC_PROPERTY_NAME_ERROR"},
   { 2443, "MQRC_SEGMENTATION_NOT_ALLOWED"},
   { 2444, "MQRC_CBD_ERROR"},
   { 2445, "MQRC_CTLO_ERROR"},
   { 2446, "MQRC_NO_CALLBACKS_ACTIVE"},
   { 2448, "MQRC_CALLBACK_NOT_REGISTERED"},
   { 2457, "MQRC_OPTIONS_CHANGED"},
   { 2458, "MQRC_READ_AHEAD_MSGS"},
   { 2459, "MQRC_SELECTOR_SYNTAX_ERROR"},
   { 2460, "MQRC_HMSG_ERROR"},
   { 2461, "MQRC_CMHO_ERROR"},
   { 2462, "MQRC_DMHO_ERROR"},
   { 2463, "MQRC_SMPO_ERROR"},
   { 2464, "MQRC_IMPO_ERROR"},
   { 2465, "MQRC_PROPERTY_NAME_TOO_BIG"},
   { 2466, "MQRC_PROP_VALUE_NOT_CONVERTED"},
   { 2467, "MQRC_PROP_TYPE_NOT_SUPPORTED"},
   { 2469, "MQRC_PROPERTY_VALUE_TOO_BIG"},
   { 2470, "MQRC_PROP_CONV_NOT_SUPPORTED"},
   { 2471, "MQRC_PROPERTY_NOT_AVAILABLE"},
   { 2472, "MQRC_PROP_NUMBER_FORMAT_ERROR"},
   { 2473, "MQRC_PROPERTY_TYPE_ERROR"},
   { 2478, "MQRC_PROPERTIES_TOO_BIG"},
   { 2479, "MQRC_PUT_NOT_RETAINED"},
   { 2480, "MQRC_ALIAS_TARGTYPE_CHANGED"},
   { 2481, "MQRC_DMPO_ERROR"},
   { 2482, "MQRC_PD_ERROR"},
   { 2483, "MQRC_CALLBACK_TYPE_ERROR"},
   { 2484, "MQRC_CBD_OPTIONS_ERROR"},
   { 2485, "MQRC_MAX_MSG_LENGTH_ERROR"},
   { 2486, "MQRC_CALLBACK_ROUTINE_ERROR"},
   { 2487, "MQRC_CALLBACK_LINK_ERROR"},
   { 2488, "MQRC_OPERATION_ERROR"},
   { 2489, "MQRC_BMHO_ERROR"},
   { 2490, "MQRC_UNSUPPORTED_PROPERTY"},
   { 2492, "MQRC_PROP_NAME_NOT_CONVERTED"},
   { 2494, "MQRC_GET_ENABLED"},
   { 2495, "MQRC_MODULE_NOT_FOUND"},
   { 2496, "MQRC_MODULE_INVALID"},
   { 2497, "MQRC_MODULE_ENTRY_NOT_FOUND"},
   { 2498, "MQRC_MIXED_CONTENT_NOT_ALLOWED"},
   { 2499, "MQRC_MSG_HANDLE_IN_USE"},
   { 2500, "MQRC_HCONN_ASYNC_ACTIVE"},
   { 2501, "MQRC_MHBO_ERROR"},
   { 2502, "MQRC_PUBLICATION_FAILURE"},
   { 2503, "MQRC_SUB_INHIBITED"},
   { 2504, "MQRC_SELECTOR_ALWAYS_FALSE"},
   { 2507, "MQRC_XEPO_ERROR"},
   { 2509, "MQRC_DURABILITY_NOT_ALTERABLE"},
   { 2510, "MQRC_TOPIC_NOT_ALTERABLE"},
   { 2512, "MQRC_SUBLEVEL_NOT_ALTERABLE"},
   { 2513, "MQRC_PROPERTY_NAME_LENGTH_ERR"},
   { 2514, "MQRC_DUPLICATE_GROUP_SUB"},
   { 2515, "MQRC_GROUPING_NOT_ALTERABLE"},
   { 2516, "MQRC_SELECTOR_INVALID_FOR_TYPE"},
   { 2517, "MQRC_HOBJ_QUIESCED"},
   { 2518, "MQRC_HOBJ_QUIESCED_NO_MSGS"},
   { 2519, "MQRC_SELECTION_STRING_ERROR"},
   { 2520, "MQRC_RES_OBJECT_STRING_ERROR"},
   { 2521, "MQRC_CONNECTION_SUSPENDED"},
   { 2522, "MQRC_INVALID_DESTINATION"},
   { 2523, "MQRC_INVALID_SUBSCRIPTION"},
   { 2524, "MQRC_SELECTOR_NOT_ALTERABLE"},
   { 2525, "MQRC_RETAINED_MSG_Q_ERROR"},
   { 2526, "MQRC_RETAINED_NOT_DELIVERED"},
   { 2527, "MQRC_RFH_RESTRICTED_FORMAT_ERR"},
   { 2528, "MQRC_CONNECTION_STOPPED"},
   { 2529, "MQRC_ASYNC_UOW_CONFLICT"},
   { 2530, "MQRC_ASYNC_XA_CONFLICT"},
   { 2531, "MQRC_PUBSUB_INHIBITED"},
   { 2532, "MQRC_MSG_HANDLE_COPY_FAILURE"},
   { 2533, "MQRC_DEST_CLASS_NOT_ALTERABLE"},
   { 2534, "MQRC_OPERATION_NOT_ALLOWED"},
   { 2535, "MQRC_ACTION_ERROR"},
   { 2537, "MQRC_CHANNEL_NOT_AVAILABLE"},
   { 2538, "MQRC_HOST_NOT_AVAILABLE"},
   { 2539, "MQRC_CHANNEL_CONFIG_ERROR"},
   { 2540, "MQRC_UNKNOWN_CHANNEL_NAME"},
   { 2541, "MQRC_LOOPING_PUBLICATION"},
   { 2542, "MQRC_ALREADY_JOINED"},
   { 2543, "MQRC_STANDBY_Q_MGR"},
   { 2544, "MQRC_RECONNECTING"},
   { 2545, "MQRC_RECONNECTED"},
   { 2546, "MQRC_RECONNECT_QMID_MISMATCH"},
   { 2547, "MQRC_RECONNECT_INCOMPATIBLE"},
   { 2548, "MQRC_RECONNECT_FAILED"},
   { 2549, "MQRC_CALL_INTERRUPTED"},
   { 2550, "MQRC_NO_SUBS_MATCHED"},
   { 2551, "MQRC_SELECTION_NOT_AVAILABLE"},
   { 2552, "MQRC_CHANNEL_SSL_WARNING"},
   { 2553, "MQRC_OCSP_URL_ERROR"},
   { 2554, "MQRC_CONTENT_ERROR"},
   { 2555, "MQRC_RECONNECT_Q_MGR_REQD"},
   { 2556, "MQRC_RECONNECT_TIMED_OUT"},
   { 2557, "MQRC_PUBLISH_EXIT_ERROR"},
   { 2558, "MQRC_COMMINFO_ERROR"},
   { 2559, "MQRC_DEF_SYNCPOINT_INHIBITED"},
   { 2560, "MQRC_MULTICAST_ONLY"},
   { 2561, "MQRC_DATA_SET_NOT_AVAILABLE"},
   { 2562, "MQRC_GROUPING_NOT_ALLOWED"},
   { 2563, "MQRC_GROUP_ADDRESS_ERROR"},
   { 2564, "MQRC_MULTICAST_CONFIG_ERROR"},
   { 2565, "MQRC_MULTICAST_INTERFACE_ERROR"},
   { 2566, "MQRC_MULTICAST_SEND_ERROR"},
   { 2567, "MQRC_MULTICAST_INTERNAL_ERROR"},
   { 2568, "MQRC_CONNECTION_NOT_AVAILABLE"},
   { 2569, "MQRC_SYNCPOINT_NOT_ALLOWED"},
   { 2570, "MQRC_SSL_ALT_PROVIDER_REQUIRED"},
   { 2571, "MQRC_MCAST_PUB_STATUS"},
   { 2572, "MQRC_MCAST_SUB_STATUS"},
   { 2573, "MQRC_PRECONN_EXIT_LOAD_ERROR"},
   { 2574, "MQRC_PRECONN_EXIT_NOT_FOUND"},
   { 2575, "MQRC_PRECONN_EXIT_ERROR"},
   { 2576, "MQRC_CD_ARRAY_ERROR"},
   { 2577, "MQRC_CHANNEL_BLOCKED"},
   { 2578, "MQRC_CHANNEL_BLOCKED_WARNING"},
   { 2579, "MQRC_SUBSCRIPTION_CREATE"},
   { 2580, "MQRC_SUBSCRIPTION_DELETE"},
   { 2581, "MQRC_SUBSCRIPTION_CHANGE"},
   { 2582, "MQRC_SUBSCRIPTION_REFRESH"},
   { 2583, "MQRC_INSTALLATION_MISMATCH"},
   { 2584, "MQRC_NOT_PRIVILEGED"},
   { 2586, "MQRC_PROPERTIES_DISABLED"},
   { 2587, "MQRC_HMSG_NOT_AVAILABLE"},
   { 2588, "MQRC_EXIT_PROPS_NOT_SUPPORTED"},
   { 2589, "MQRC_INSTALLATION_MISSING"},
   { 2590, "MQRC_FASTPATH_NOT_AVAILABLE"},
   { 2591, "MQRC_CIPHER_SPEC_NOT_SUITE_B"},
   { 2592, "MQRC_SUITE_B_ERROR"},
   { 2593, "MQRC_CERT_VAL_POLICY_ERROR"},
   { 2594, "MQRC_PASSWORD_PROTECTION_ERROR"},
   { 2595, "MQRC_CSP_ERROR"},
   { 2596, "MQRC_CERT_LABEL_NOT_ALLOWED"},
   { 2598, "MQRC_ADMIN_TOPIC_STRING_ERROR"},
   { 2599, "MQRC_AMQP_NOT_AVAILABLE"},
   { 2600, "MQRC_CCDT_URL_ERROR"},
   { 2601, "MQRC_Q_MGR_RECONNECT_REQUESTED"},
   { 6100, "MQRC_REOPEN_EXCL_INPUT_ERROR"},
   { 6101, "MQRC_REOPEN_INQUIRE_ERROR"},
   { 6102, "MQRC_REOPEN_SAVED_CONTEXT_ERR"},
   { 6103, "MQRC_REOPEN_TEMPORARY_Q_ERROR"},
   { 6104, "MQRC_ATTRIBUTE_LOCKED"},
   { 6105, "MQRC_CURSOR_NOT_VALID"},
   { 6106, "MQRC_ENCODING_ERROR"},
   { 6107, "MQRC_STRUC_ID_ERROR"},
   { 6108, "MQRC_NULL_POINTER"},
   { 6109, "MQRC_NO_CONNECTION_REFERENCE"},
   { 6110, "MQRC_NO_BUFFER"},
   { 6111, "MQRC_BINARY_DATA_LENGTH_ERROR"},
   { 6112, "MQRC_BUFFER_NOT_AUTOMATIC"},
   { 6113, "MQRC_INSUFFICIENT_BUFFER"},
   { 6114, "MQRC_INSUFFICIENT_DATA"},
   { 6115, "MQRC_DATA_TRUNCATED"},
   { 6116, "MQRC_ZERO_LENGTH"},
   { 6117, "MQRC_NEGATIVE_LENGTH"},
   { 6118, "MQRC_NEGATIVE_OFFSET"},
   { 6119, "MQRC_INCONSISTENT_FORMAT"},
   { 6120, "MQRC_INCONSISTENT_OBJECT_STATE"},
   { 6121, "MQRC_CONTEXT_OBJECT_NOT_VALID"},
   { 6122, "MQRC_CONTEXT_OPEN_ERROR"},
   { 6124, "MQRC_NOT_CONNECTED"},
   { 6125, "MQRC_NOT_OPEN"},
   { 6126, "MQRC_DISTRIBUTION_LIST_EMPTY"},
   { 6127, "MQRC_INCONSISTENT_OPEN_OPTIONS"},
   { 6128, "MQRC_WRONG_VERSION"},
   { 6129, "MQRC_REFERENCE_ERROR"},
   { 6130, "MQRC_XR_NOT_AVAILABLE"},
   {29440, "MQRC_SUB_JOIN_NOT_ALTERABLE"}
};

static int REASON_CODES_SIZE = sizeof(REASON_CODES) / sizeof(MQ_LOOK_UP_T);

/**
 * Function Name
 *  BinarySearch
 *
 * Description
 *  This function will perform a binary search and return an
 *  index to the matching item.
 *
 * Input parameters
 *  int searchItem       - integer value to lookup
 *  MQ_LOOK_UP_T *pArray - pointer to lookup array
 *  int n                - number of items in the array
 *
 * Return Value
 *  index or NOT_FOUND
 *
 */
int BinarySearch(int searchItem, MQ_LOOK_UP_T *pArray, int n)
{
   /* --------------------------------------------
    * Variable declarations.
    * --------------------------------------------
    */
   int Low = 0;
   int Mid;
   int High = n - 1;

   /* --------------------------------------------
    * Code section
    * --------------------------------------------
    */
   while( Low <= High )
   {
      Mid = ( Low + High ) / 2;
      if( pArray[Mid].Index < searchItem )
         Low = Mid + 1;
      else if( pArray[Mid].Index > searchItem )
         High = Mid - 1;
      else
         return Mid;  /* Found */
   }
   return NOT_FOUND;
}

/**
 * Function Name
 *  Lookup_MQCC
 *
 * Description
 *  This function will return the MQ Completion Code as a string.
 *
 * Input parameters
 *  int iValue     - value to look up
 *  char *pTempBuf - buffer to hold string representation of iValue if iValue is not found.
 *
 * Return Value
 *  char * - pointer to the string
 */
char *Lookup_MQCC(int iValue, char *pTempBuf)
{
   /* --------------------------------------------
    * Variable declarations.
    * --------------------------------------------
    */

   /* --------------------------------------------
    * Code section
    * --------------------------------------------
    */
   switch (iValue)
   {
      case 0:
         return COMPLETION_CODES[1].pString;
         break;
      case 1:
         return COMPLETION_CODES[2].pString;
         break;
      case 2:
         return COMPLETION_CODES[3].pString;
         break;
      case -1:
         return COMPLETION_CODES[0].pString;
         break;
      default:
         sprintf(pTempBuf, "%d", iValue);
         return pTempBuf;
         break;
   }
}

/**
 * Function Name
 *  Lookup_MQRC
 *
 * Description
 *  This function will return the MQ Reason Code as a string.
 *
 * Input parameters
 *  int iValue     - value to look up
 *  char *pTempBuf - buffer to hold string representation of iValue if iValue is not found.
 *
 * Return Value
 *  char * - pointer to the string
 */
char * Lookup_MQRC(int iValue, char *pTempBuf)
{
   /* --------------------------------------------
    * Variable declarations.
    * --------------------------------------------
    */
   int   index;

   /* --------------------------------------------
    * Code section
    * --------------------------------------------
    */
   index = BinarySearch( iValue,
                         REASON_CODES,
                         REASON_CODES_SIZE );

   if (NOT_FOUND != index)
      return REASON_CODES[index].pString;
   else
   {
      sprintf(pTempBuf, "%d", iValue);
      return pTempBuf;
   }
}

#endif  /* End of header file */
